@@ -5,9 +5,13 @@
 EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
+
     Lewis Rowles <stetsonsc@gmail.com>
+
     Yalin Li <mailto.yalin.li@gmail.com>
+
     Hannah Lohman <hlohman94@gmail.com>
+
     Lane To <lane20@illinois.edu>
 
 This module is under the University of Illinois/NCSA Open Source License.
@@ -128,8 +132,42 @@ def add_shared_parameters(model, unit_dct, country_specific=False):
     # Add these parameters if not running country-specific analysis,
     # in which they would be updated separately
     if not country_specific:
-        # Household size
+        # Price ratio
+        # Just want to have this parameter so that can be used in other analyses,
+        # set the distribution to be a really tight one
+        old_price_dct = price_dct.copy()
         excretion_unit = unit_dct['Excretion']
+        b = 1
+        D = shape.Uniform(lower=b-(10**(-6)), upper=b+(10**(-6)))
+        item_ref = {
+            'Concrete': 'Concrete',
+            'Steel': 'Steel',
+        }
+        stream_ref = {
+            'Polymer': 'polymer',
+            'Resin': 'resin',
+            'FilterBag': 'filter_bag',
+            'MgOH2': 'MgOH2',
+            'MgCO3': 'MgCO3',
+            'H2SO4': 'H2SO4',
+            'biochar': 'biochar',
+        }
+        @param(name='Price ratio', element=excretion_unit, kind='cost', units='-',
+               baseline=b, distribution=D)
+        def set_price_ratio(i):
+            br.price_ratio = i
+            for obj_name in (*item_ref.keys(), *stream_ref.keys()):
+                old_price = old_price_dct[obj_name]
+                new_price = old_price * i
+                if obj_name in item_ref.keys():
+                    ImpactItem.get_item(item_ref[obj_name]).price = new_price
+                else:
+                    getattr(sys_stream, stream_ref[obj_name]).price = new_price
+            for u in sys.units:
+                if hasattr(u, 'price_ratio'):
+                    u.price_ratio = i
+        
+        # Household size
         b = br.household_size
         D = shape.Normal(mu=b, sigma=0.012)
         @param(name='Household size', element=excretion_unit, kind='coupled', units='cap/household',
@@ -819,9 +857,11 @@ def add_pit_latrine_parameters(model, unit_dct):
 # Functions to create models
 # =============================================================================
 
-def create_modelA(country_specific=False, **model_kwargs):
+def create_modelA(country_specific=False, adjust_MW_to_measured_as=False, 
+                  **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysA = create_system('A', flowsheet=flowsheet)
+    sysA = create_system('A', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitA = sysA.flowsheet.unit
 
     # Shared metrics/parameters
@@ -849,9 +889,11 @@ def create_modelA(country_specific=False, **model_kwargs):
     return modelA
 
 
-def create_modelB(country_specific=False, **model_kwargs):
+def create_modelB(country_specific=False, adjust_MW_to_measured_as=False,
+                  **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysB = create_system('B', flowsheet=flowsheet)
+    sysB = create_system('B', flowsheet=flowsheet,
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitB = sysB.flowsheet.unit
 
     # Shared parameters
@@ -932,9 +974,11 @@ def create_modelB(country_specific=False, **model_kwargs):
     return modelB
 
 
-def create_modelC(country_specific=False, **model_kwargs):
+def create_modelC(country_specific=False, adjust_MW_to_measured_as=False, 
+                  **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysC = create_system('C', flowsheet=flowsheet)
+    sysC = create_system('C', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitC = sysC.flowsheet.unit
 
     # Shared parameters
@@ -964,9 +1008,11 @@ def create_modelC(country_specific=False, **model_kwargs):
 
 # The `country_specific` kwarg is just a placeholder to be consistent
 # with other systems, isn't actually being used
-def create_modelD(country_specific=False, **model_kwargs):
+def create_modelD(country_specific=False, adjust_MW_to_measured_as=False, 
+                  **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysD = create_system('D', flowsheet=flowsheet)
+    sysD = create_system('D', flowsheet=flowsheet,
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitD = sysD.flowsheet.unit
     modelD = Model(sysD, **model_kwargs)
     add_metrics(modelD)
@@ -1003,13 +1049,15 @@ def create_modelD(country_specific=False, **model_kwargs):
 
 
 # Wrapper function so that it'd work for all
-def create_model(model_ID='A', country_specific=False, **model_kwargs):
+def create_model(model_ID='A', country_specific=False, 
+                 adjust_MW_to_measured_as=False, **model_kwargs):
     model_ID = model_ID.lower().rsplit('model')[-1].rsplit('sys')[-1].upper() # works for "modelA"/"sysA"/"A"
-    if model_ID == 'A': model = create_modelA(country_specific, **model_kwargs)
-    elif model_ID == 'B': model = create_modelB(country_specific, **model_kwargs)
-    elif model_ID == 'C': model = create_modelC(country_specific, **model_kwargs)
-    elif model_ID == 'D': model = create_modelD(country_specific, **model_kwargs)
+    if model_ID == 'A': f = create_modelA
+    elif model_ID == 'B': f = create_modelB
+    elif model_ID == 'C': f = create_modelC
+    elif model_ID == 'D': f = create_modelD
     else: raise ValueError(f'`model_ID` can only be "A", "B", "C", or "D", not "{model_ID}".')
+    model = f(country_specific, adjust_MW_to_measured_as, **model_kwargs)
     return model
 
 
