@@ -5,9 +5,13 @@
 EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
+
     Lewis Rowles <stetsonsc@gmail.com>
+
     Yalin Li <mailto.yalin.li@gmail.com>
+
     Hannah Lohman <hlohman94@gmail.com>
+
     Lane To <lane20@illinois.edu>
 
 This module is under the University of Illinois/NCSA Open Source License.
@@ -20,7 +24,7 @@ from qsdsan import (
     WasteStream,
     sanunits as su,
     ImpactItem,
-    System, SimpleTEA, LCA,
+    System, TEA, LCA,
     )
 from qsdsan.utils import clear_lca_registries
 from exposan.utils import add_fugitive_items
@@ -194,10 +198,10 @@ def create_systemA(flowsheet=None):
 
     ##### Simulation, TEA, and LCA #####
     sysA = System('sysA', path=(A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12, A13, A14, A15))
-    teaA = SimpleTEA(system=sysA, discount_rate=discount_rate,
-                      start_year=2020, lifetime=20, uptime_ratio=1,
-                      lang_factor=None, annual_maintenance=0,
-                      annual_labor=(operator_daily_wage*3*365))
+    teaA = TEA(system=sysA, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=(operator_daily_wage*3*365))
 
     # 12 is assuming the device is running 12 hr per day (50% of the time)
     # this isn't adjusted through `uptime_ratio` because other OPEX calculation
@@ -321,10 +325,10 @@ def create_systemB(flowsheet=None):
 
     ##### Simulation, TEA, and LCA #####
     sysB = System('sysB', path=(B1, B2, B3, B4, B5, B6, B7, B8, B9, B10, B11, B12, B13, B14, B15, B16, B17, B18))
-    teaB = SimpleTEA(system=sysB, discount_rate=discount_rate,
-                      start_year=2020, lifetime=20, uptime_ratio=1,
-                      lang_factor=None, annual_maintenance=0,
-                      annual_labor=(operator_daily_wage*3*365))
+    teaB = TEA(system=sysB, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=(operator_daily_wage*3*365))
 
     # 12 is assuming the device is running 12 hr per day (50% of the time)
     # this isn't adjusted through `uptime_ratio` because other OPEX calculation
@@ -430,10 +434,10 @@ def create_systemC(flowsheet=None):
     ##### Simulation, TEA, and LCA #####
     sysC = System('sysC', path=(C1, C2, C3, C4, C5, C6, C7, C_ag_mixer, C8, C9, C10, C11, C12, C13, C14))
 
-    teaC = SimpleTEA(system=sysC, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0,
-                     annual_labor=(operator_daily_wage*3*365))
+    teaC = TEA(system=sysC, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=(operator_daily_wage*3*365))
 
     # 12 is assuming the device is running 12 hr per day (50% of the time)
     # this isn't adjusted through `uptime_ratio` because other OPEX calculation
@@ -512,9 +516,9 @@ def create_systemD(flowsheet=None):
     sysD = System('sysD', path=(D1, D2, D3, D4, D5, D6, D7))
     sysD.simulate()
 
-    teaD = SimpleTEA(system=sysD, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0)
+    teaD = TEA(system=sysD, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0)
 
     # 12 is assuming the device is running 12 hr per day (50% of the time)
     # this isn't adjusted through `uptime_ratio` because other OPEX calculation
@@ -532,7 +536,7 @@ def create_systemD(flowsheet=None):
 # Wrapper function
 # =============================================================================
 
-def create_system(system_ID='A', flowsheet=None):
+def create_system(system_ID='A', flowsheet=None, adjust_MW_to_measured_as=False):
     ID = system_ID.lower().lstrip('sys').upper() # so that it'll work for "sysA"/"A"
     reload_lca = False
 
@@ -546,7 +550,7 @@ def create_system(system_ID='A', flowsheet=None):
         flowsheet = Flowsheet(flowsheet_ID)
         main_flowsheet.set_flowsheet(flowsheet)
 
-    _load_components()
+    _load_components(adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     _load_lca_data(reload_lca)
 
     if system_ID == 'A': f = create_systemA
@@ -557,7 +561,7 @@ def create_system(system_ID='A', flowsheet=None):
 
     try: system = f(flowsheet)
     except:
-        _load_components(reload=True)
+        _load_components(reload=True, adjust_MW_to_measured_as=adjust_MW_to_measured_as)
         system = f(flowsheet)
 
     return system
\ No newline at end of file
