@@ -2,12 +2,19 @@
 # -*- coding: utf-8 -*-
 
 '''
-DMsan: Decision-making for sanitation and resource recovery systems
+EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
+    
     Tori Morgan <tvlmorgan@gmail.com>
+    
     Hannah Lohman <hlohman94@gmail.com>
+    
     Yalin Li <mailto.yalin.li@gmail.com>
+
+This module is under the University of Illinois/NCSA Open Source License.
+Please refer to https://github.com/QSD-Group/EXPOsan/blob/main/LICENSE.txt
+for license details.
 '''
 
 
@@ -111,8 +118,22 @@ def add_shared_parameters(model, unit_dct, country_specific=False):
     # Add these parameters if not running country-specific analysis,
     # in which they would be updated separately
 
+    excretion_unit = unit_dct['Excretion']
+    
     if not country_specific:
-
+        # Price ratio
+        # Just want to have this parameter so that can be used in other analyses,
+        # set the distribution to be a really tight one
+        b = 1
+        D = shape.Uniform(lower=b-(10**(-6)), upper=b+(10**(-6)))
+        @param(name='Price ratio', element=excretion_unit, kind='cost', units='-',
+               baseline=b, distribution=D)
+        def set_price_ratio(i):
+            re.price_ratio = i
+            for u in sys.units:
+                if hasattr(u, 'price_ratio'):
+                    u.price_ratio = i
+        
         # Labor wage
         b = price_dct['wages']
         D = shape.Triangle(lower=1.82, midpoint=b, upper=5.46)  # wage in USD/hour
@@ -209,7 +230,6 @@ def add_shared_parameters(model, unit_dct, country_specific=False):
 
     ##### Specific units #####
     # Diet and excretion
-    excretion_unit = unit_dct['Excretion']
     exclude = ('e_cal', 'p_anim', 'p_veg') if country_specific else ()
     batch_setting_unit_params(excretion_data, model, excretion_unit, exclude)
 
@@ -255,7 +275,7 @@ def add_shared_parameters(model, unit_dct, country_specific=False):
 
     # Sludge pasteurization
     # `wages` should be excluded for all units this this attribute
-    exclude = 'wages' if country_specific else ()
+    exclude = 'wages'
     pasteurization_unit = unit_dct.get('Pasteurization')
     if pasteurization_unit: batch_setting_unit_params(pasteurization_data, model, pasteurization_unit, exclude)
 
@@ -683,9 +703,10 @@ def add_shared_parameters(model, unit_dct, country_specific=False):
 # =============================================================================
 
 # System A: Solids removal only
-def create_modelA(country_specific=False, **model_kwargs):
+def create_modelA(country_specific=False, adjust_MW_to_measured_as=False, **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysA = create_system('A', flowsheet=flowsheet)
+    sysA = create_system('A', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitA = sysA.flowsheet.unit
 
     # Shared metrics/parameters
@@ -702,9 +723,10 @@ def create_modelA(country_specific=False, **model_kwargs):
 
 
 # System B: Full Duke system with grid electricity source
-def create_modelB(country_specific=False, **model_kwargs):
+def create_modelB(country_specific=False, adjust_MW_to_measured_as=False, **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysB = create_system('B', flowsheet=flowsheet)
+    sysB = create_system('B', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitB = sysB.flowsheet.unit
 
     # Shared parameters
@@ -727,9 +749,10 @@ def create_modelB(country_specific=False, **model_kwargs):
 
 
 # System C: Full Duke system with solar electricity source
-def create_modelC(country_specific=False, **model_kwargs):
+def create_modelC(country_specific=False, adjust_MW_to_measured_as=False, **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysC = create_system('C', flowsheet=flowsheet)
+    sysC = create_system('C', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitC = sysC.flowsheet.unit
 
     # Shared parameters
@@ -752,9 +775,10 @@ def create_modelC(country_specific=False, **model_kwargs):
 
 
 # System D: Targeted nitrogen removal (created for NSS preliminary analysis)
-def create_modelD(country_specific=False, **model_kwargs):
+def create_modelD(country_specific=False, adjust_MW_to_measured_as=False, **model_kwargs):
     flowsheet = model_kwargs.pop('flowsheet', None)
-    sysD = create_system('D', flowsheet=flowsheet)
+    sysD = create_system('D', flowsheet=flowsheet, 
+                         adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     unitD = sysD.flowsheet.unit
 
     # Shared parameters
@@ -774,13 +798,15 @@ def create_modelD(country_specific=False, **model_kwargs):
 
 
 # Wrapper function so that it'd work for all
-def create_model(model_ID='A', country_specific=False, **model_kwargs):
+def create_model(model_ID='A', country_specific=False, 
+                 adjust_MW_to_measured_as=False, **model_kwargs):
     model_ID = model_ID.lower().rsplit('model')[-1].rsplit('sys')[-1].upper() # works for "modelA"/"sysA"/"A"
-    if model_ID == 'A': model = create_modelA(country_specific, **model_kwargs)
-    elif model_ID == 'B': model = create_modelB(country_specific, **model_kwargs)
-    elif model_ID == 'C': model = create_modelC(country_specific, **model_kwargs)
-    elif model_ID == 'D': model = create_modelD(country_specific, **model_kwargs)
+    if model_ID == 'A': f = create_modelA
+    elif model_ID == 'B': f = create_modelB
+    elif model_ID == 'C': f = create_modelC
+    elif model_ID == 'D': f = create_modelD
     else: raise ValueError(f'`model_ID` can only be "A", "B", "C", or "D", not "{model_ID}".')
+    model = f(country_specific, adjust_MW_to_measured_as, **model_kwargs)
     return model
 
 
