@@ -5,8 +5,11 @@
 EXPOsan: Exposition of sanitation and resource recovery systems
 
 This module is developed by:
+
     Tori Morgan <tvlmorgan@gmail.com>
+
     Hannah Lohman <hlohman94@gmail.com>
+
     Yalin Li <mailto.yalin.li@gmail.com>
 
 This module is under the University of Illinois/NCSA Open Source License.
@@ -19,7 +22,7 @@ from qsdsan import (
     WasteStream,
     sanunits as su,
     ImpactItem,
-    System, SimpleTEA, LCA,
+    System, TEA, LCA,
     )
 from qsdsan.utils import clear_lca_registries
 from exposan.utils import add_fugitive_items
@@ -117,10 +120,10 @@ def create_systemA(flowsheet=None):
     ##### Simulation, TEA, and LCA #####
     sysA = System('sysA', path=(A1, A3, A4, A8, A9))
 
-    teaA = SimpleTEA(system=sysA, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0,
-                     annual_labor=0)
+    teaA = TEA(system=sysA, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=0)
 
     get_powerA = lambda: sum([u.power_utility.rate for u in sysA.units]) * (24 * 365 * teaA.lifetime)
 
@@ -208,10 +211,10 @@ def create_systemB(flowsheet=None):
     ##### Simulation, TEA, and LCA #####
     sysB = System('sysB', path=(B1, B2, B3, B4, B5, B6, B7, B8, B9, B10, B11, B12))
 
-    teaB = SimpleTEA(system=sysB, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0,
-                     annual_labor=0)
+    teaB = TEA(system=sysB, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=0)
 
     get_powerB = lambda: sum([u.power_utility.rate for u in sysB.units]) * (24 * 365 * teaB.lifetime)
 
@@ -307,10 +310,10 @@ def create_systemC(flowsheet=None):
     ##### Simulation, TEA, and LCA #####
     sysC = System('sysC', path=(C1, C2, C3, C4, C5, C6, C7, C8, C9, C10, C11, C12, C13))
 
-    teaC = SimpleTEA(system=sysC, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0,
-                     annual_labor=0)
+    teaC = TEA(system=sysC, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=0)
 
     get_powerC = lambda: sum([u.power_utility.rate for u in sysC.units]) * (24 * 365 * teaC.lifetime)
 
@@ -369,10 +372,10 @@ def create_systemD(flowsheet=None):
     ##### Simulation, TEA, and LCA #####
     sysD = System('sysD', path=(D1, D3, D4, D5, D6, D7, D8, D9))
 
-    teaD = SimpleTEA(system=sysD, discount_rate=discount_rate,
-                     start_year=2020, lifetime=20, uptime_ratio=1,
-                     lang_factor=None, annual_maintenance=0,
-                     annual_labor=0)
+    teaD = TEA(system=sysD, discount_rate=discount_rate,
+               start_year=2020, lifetime=20, uptime_ratio=1,
+               lang_factor=None, annual_maintenance=0,
+               annual_labor=0)
 
     get_powerD = lambda: sum([u.power_utility.rate for u in sysD.units]) * (24 * 365 * teaD.lifetime)
 
@@ -387,7 +390,7 @@ def create_systemD(flowsheet=None):
 # Wrapper function
 # =============================================================================
 
-def create_system(system_ID='A', flowsheet=None):
+def create_system(system_ID='A', flowsheet=None, adjust_MW_to_measured_as=False):
     ID = system_ID.lower().lstrip('sys').upper() # so that it'll work for "sysA"/"A"
     reload_lca = False
 
@@ -401,7 +404,7 @@ def create_system(system_ID='A', flowsheet=None):
         flowsheet = Flowsheet(flowsheet_ID)
         main_flowsheet.set_flowsheet(flowsheet)
 
-    _load_components()
+    _load_components(adjust_MW_to_measured_as=adjust_MW_to_measured_as)
     _load_lca_data(reload_lca)
 
     if system_ID == 'A': f = create_systemA
@@ -412,7 +415,7 @@ def create_system(system_ID='A', flowsheet=None):
 
     try: system = f(flowsheet)
     except:
-        _load_components(reload=True)
+        _load_components(reload=True, adjust_MW_to_measured_as=adjust_MW_to_measured_as)
         system = f(flowsheet)
 
     return system
\ No newline at end of file
